# Generated by Django 2.2.4 on 2019-08-23 17:22

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_discord_connector', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='discordtoken',
            name='external_id',
        ),
        migrations.RemoveField(
            model_name='discordtoken',
            name='groups',
        ),
        migrations.RemoveField(
            model_name='discordtoken',
            name='nickname',
        ),
        migrations.RemoveField(
            model_name='discordtoken',
            name='username',
        ),
        migrations.CreateModel(
            name='DiscordUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('username', models.CharField(max_length=255)),
                ('nickname', models.CharField(max_length=255)),
                ('external_id', models.BigIntegerField()),
                ('groups', models.ManyToManyField(to='django_discord_connector.DiscordGroup')),
            ],
        ),
        migrations.AddField(
            model_name='discordtoken',
            name='discord_user',
            field=models.OneToOneField(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='discord_token', to='django_discord_connector.DiscordUser'),
        ),
    ]
