# Generated by Django 2.2.4 on 2019-09-04 16:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_discord_connector', '0004_auto_20190826_1348'),
    ]

    operations = [
        migrations.AlterField(
            model_name='discorduser',
            name='groups',
            field=models.ManyToManyField(blank=True, to='django_discord_connector.DiscordGroup'),
        ),
        migrations.AlterField(
            model_name='discorduser',
            name='nickname',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
