# Generated by Django 2.2.13 on 2020-11-20 21:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_discord_connector', '0009_auto_20200929_2007'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='discordclient',
            options={'verbose_name': 'Discord Settings', 'verbose_name_plural': 'Discord Settings'},
        ),
    ]
