# Generated by Django 2.2.4 on 2019-09-18 19:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_discord_connector', '0005_auto_20190904_1643'),
    ]

    operations = [
        migrations.AlterField(
            model_name='discorduser',
            name='nickname',
            field=models.CharField(default='Test', max_length=255),
            preserve_default=False,
        ),
    ]
