# Generated by Django 2.2.4 on 2019-11-18 14:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_discord_connector', '0006_auto_20190918_1914'),
    ]

    operations = [
        migrations.RenameField(
            model_name='discordclient',
            old_name='secret',
            new_name='client_secret',
        ),
        migrations.AlterField(
            model_name='discordclient',
            name='client_id',
            field=models.TextField(),
        ),
        migrations.AlterField(
            model_name='discordclient',
            name='server_id',
            field=models.TextField(),
        ),
    ]
